@@ -1,4 +1,4 @@
-/* $Id: VBoxNetFlt-linux.c 87653 2013-07-31 09:52:56Z fmehnert $ */
+/* $Id: VBoxNetFlt-linux.c 87651 2013-07-31 09:30:33Z fmehnert $ */
 /** @file
  * VBoxNetFlt - Network Filter Driver (Host), Linux Specific Code.
  */
@@ -445,7 +445,7 @@ static void vboxNetFltLinuxUnhookDev(PVBOXNETFLTINS pThis, struct net_device *pD
 
     if (pOverride)
     {
-        printk("vboxnetflt: dropped %llu out of %llu packets\n", pOverride->cFiltered, pOverride->cTotal);
+        printk("vboxnetflt: %llu out of %llu packets were not sent (directed to host)\n", pOverride->cFiltered, pOverride->cTotal);
         RTMemFree(pOverride);
     }
 }
